import { LogInput } from './types/LogInput';
import { LogInputError } from './types/LogInputError';
import { LogLevels } from './types/logLevels';
import { LogOptions } from './types/LogOptions';
import { LogOutput } from './types/LogOutput';
/**
 * Provides methods for writing logs to in different log-levels. Logs are written in JSON format to stdout using console.log().
 */
declare class Logger {
    /**
     * This governs which logs will be written. If log level is
     * INFO all logs with INFO and above will be written. So: INFO
     * WARN and ERROR.
     */
    level: LogLevels;
    /**
     * Sets a reference to the AWS lambda context object and will enrich the logs with context meta data to make it easier to track.
     */
    context: AWSLambda.Context | undefined;
    /**
     * The id that came from the service that called this lambda.
     * It is best practice to send this through a header called X-REQUEST-ID.
     * In most cases you would set this to that header if it exist.
     */
    xRequestId: string | undefined;
    /**
     * The user agent that called this service.
     * In API Gateway events it can be found here: event.headers["User-Agent"]
     */
    useragent?: string;
    /**
     * The http verb (GET|POST...)
     * * In API Gateway events it can be found here: event.httpMethod
     */
    verb?: string;
    /**
     * The host of this service.
     * * In API Gateway events it can be found here: event.headers["Host"]
     */
    host?: string;
    /**
     * The host of this service.
     * * In API Gateway events it can be found here: event.queryStringParameters
     */
    query?: any;
    /**
     * The http path of this service.
     * * In API Gateway events it can be found here: event.path
     */
    path?: string;
    /**
     * Setup the meta data that will be added to all logs, this gives richer logs that will provide more value when they are sent to a log aggregator.
     */
    setup(options: LogOptions): void;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {message: 'This is my message', context: AwsLambdaContext, xRequestId: 'id-from-external-system', something: 'my property', somethingElse: 'another extra property' }
     */
    debug(logInput: LogInput): void;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {message: 'This is my message', context: AwsLambdaContext, xRequestId: 'id-from-external-system', something: 'my property', somethingElse: 'another extra property' }
     */
    info(logInput: LogInput): void;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {message: 'This is my message', context: AwsLambdaContext, xRequestId: 'id-from-external-system', something: 'my property', somethingElse: 'another extra property' }
     */
    warn(logInput: LogInput): void;
    /**
     * Prints an enriched log as JSON to stdout with newline.
     * @param logInput {
     * message: 'This is my message',
     * context: AwsLambdaContext,
     * xRequestId: 'id-from-external-system',
     * something: 'my property',
     * somethingElse: 'another extra property' }
     */
    error(logInput: LogInputError): void;
    private createLogJson;
    /**
     * If we find a property of type Error we cannot stringify it directly because it
     * will just be outputted as "{}", instead if we find an instanceof Error we add
     * the stack to a stack property.
     */
    private preProcessErrorProperties;
}
declare const log: Logger;
export { log, LogLevels, LogInput, LogOutput };
